% script to combine BGOS-AWAC deployments
% J. Thomson, Sep 2020

clear all

mooring = 'D'; % 'A' or 'D'

%% load deployment files and combine, making ice histogram plots along the way

figure(12), clf

dlist = dir(['../BGEP-' mooring '_AWAC_20*']);
counter = 0;
for di = 1:length(dlist)
    load(['../' dlist(di).name '/' dlist(di).name '.mat'])
    if ~isempty(AWAC),
        AWACall(counter + [1:length(AWAC)]) = AWAC;
        counter = length(AWACall);
        for ai=1:length(AWAC),
            allice(:,ai) = AWAC(ai).icehistogram.Nobs;
            if ~isnan(AWAC(ai).icethickness), icebincenters = AWAC(ai).icehistogram.bincenters; end
        end
        subplot(length(dlist),1,di), 
        pcolor([AWAC.time],icebincenters,allice), shading flat
        set(gca,'XLim',[ datenum( str2num([dlist(di).name(13:16)]) ,9,1) datenum( str2num([dlist(di).name(18:21)]),9,30 ) ] )
        datetick('x','keeplimits')
        ylabel('ice [m]'), xlabel([dlist(di).name(13:end)])
        set(gca,'YLim',[0 5])
        if di==1, title(['BGOS-' mooring ]), end
        colormap gray
        cmap = colormap;
        colormap(flipud(cmap))
        cb = colorbar; cb.Label.String = 'N';
        clear allice icebincenters
    end
end

print('-dpng',[ 'BGOS-' mooring '_icehistograms.png'])


%% remove the directional moments

for ai=1:length(AWACall), 
    AWACall(ai).wavespectra = rmfield(AWACall(ai).wavespectra,'a1');
    AWACall(ai).wavespectra = rmfield(AWACall(ai).wavespectra,'b1');
    AWACall(ai).wavespectra = rmfield(AWACall(ai).wavespectra,'a2');
    AWACall(ai).wavespectra = rmfield(AWACall(ai).wavespectra,'b2');
    AWACall(ai).wavespectra = rmfield(AWACall(ai).wavespectra,'check');
end

%% save merge file with everything

clear AWAC;
AWAC = AWACall;

save(['BGOS-' mooring '_AWAC.mat'],'AWAC')

%% find ERA5 values to match
ERAlist = dir('/Volumes/Thomson/ERA5data/ERA5waves*.mat');
counter = 0;
for ei = 1:length(ERAlist),
    load(['/Volumes/Thomson/ERA5data/' ERAlist(ei).name])
    [m latmatch] = min( abs( AWAC(1).lat - wavelat ));
    [m lonmatch] = min( abs( AWAC(1).lon - wavelon) );
    ERAHs( counter + [1:length(wavetime)] )  = squeeze(squeeze(hs(:,latmatch,lonmatch)));
    ERAtime( counter + [1:length(wavetime)] ) = wavetime;
    counter = length(ERAtime);
end

%% make yearly plots of the autumn waves

[years months days hours minutes secs] = datevec([AWAC.time]);
yrange= [min(years):max(years)];

for yi = 1:length(yrange),
    figure(yi), clf
    thisyear = find(years == yrange(yi) & months > 7 & months < 12);
    startindex = find(years == yrange(yi) &  ~isnan([AWAC.sigwaveheight]),1,'first' );
    endindex = find(years == yrange(yi) &  ~isnan([AWAC.sigwaveheight]),1,'last' );
    if ~isempty(thisyear) & ~isempty(startindex) & AWAC(startindex).time ~= AWAC(endindex).time,
        thisERA = find( ERAtime < max([AWAC(thisyear).time]) & ERAtime > min([AWAC(thisyear).time]));
        subplot(4,1,1)
        plot(ERAtime(thisERA),ERAHs(thisERA),'k-'), hold on
        plot([AWAC(thisyear).time],[AWAC(thisyear).sigwaveheight],'b.')
        set(gca,'XLim',[AWAC(startindex).time AWAC(endindex).time])
        datetick('x','keeplimits'), 
        ylabel('H_s [m]')
        legend('ERA5 model','AWAC','Location','NorthWest')
        set(gca,'YLim',[0 5])
        title(['BGOS-' mooring ' AWAC ' num2str(yrange(yi),4) ])
        subplot(4,1,2)
        plot([AWAC(thisyear).time],[AWAC(thisyear).peakwaveperiod],'b.')
        set(gca,'XLim',[AWAC(startindex).time AWAC(endindex).time])
        datetick('x','keeplimits'),
        ylabel('T_P [s]')
        set(gca,'YLim',[0 16])
        subplot(2,1,2)
        gotone = false;
        for ti = 1:length(thisyear),
            E(:,ti) = AWAC(thisyear(ti)).wavespectra.energy;
            if ~isnan(E(:,ti)),
                f = AWAC(thisyear(ti)).wavespectra.freq;
                gotone = true;
            end
        end
        
        if gotone,
        E(E==0) = NaN;
        pcolor([AWAC(thisyear).time]',f,log10(E)), shading flat
        set(gca,'XLim',[AWAC(startindex).time AWAC(endindex).time])
        datetick('x','keeplimits'),
        ylabel('f [Hz]')
        end
        print('-dpng',['BGOS-' mooring '_AWAC_' num2str(yrange(yi),4) '.png'])
        clear E thisyear
    end
end

%% full time series and histograms

load(['BGOS-A_AWAC.mat'],'AWAC'); AWACA = AWAC;
load(['BGOS-D_AWAC.mat'],'AWAC'); AWACD = AWAC;

figure(10), clf
subplot(2,1,1)
plot([AWACA.time],[AWACA.sigwaveheight],'b.',[AWACD.time],[AWACD.sigwaveheight],'g.'), hold on
datetick
set(gca,'YLim',[0 5])
ylabel('H_s [m]')
legend('BGOS-A','BGOS-D')
subplot(2,1,2)
plot([AWACA.time],[AWACA.icethickness],'b.',[AWACD.time],[AWACD.icethickness],'g.'), hold on
datetick
set(gca,'YLim',[0 5])
ylabel('Ice [m]')


figure(11), clf
subplot(1,2,1)
hist([ [AWACA.sigwaveheight] [AWACD.sigwaveheight]],[0:.5:6]), hold on
xlabel('H_s [m]'), ylabel('Hours')
set(gca,'XLim',[0 5])

subplot(1,2,2)
hist([[AWACA.icethickness] [AWACD.icethickness] ] ,[0:.5:6]), hold on
xlabel('Ice_{mean} [m]'), ylabel('Hours')
set(gca,'XLim',[0 5])





